pywr.recorders.ParameterRecorder — Pywr 0.5dev documentation

# pywr.recorders.ParameterRecorder

class `pywr.recorders.` `ParameterRecorder`

  Base class for recorders that track Parameter values.

  Parameters: | model : pywr.core.Model param : pywr.parameters.Parameter The parameter to record. name : str (optional) The name of the recorder

  `__init__`($self, /, *args, **kwargs)

    Initialize self. See help(type(self)) for accurate signature.

  Methods

  `after` |
  `aggregated_value` |
  `before` |
  `finish` |
  `load` |
  `register` |
  `reset` |
  `setup` |
  `unregister` |
  `values` |

  Attributes

  `agg_func` |
  `children` |
  `comment` |
  `epsilon` |
  `ignore_nan` |
  `is_constraint` |
  `is_objective` |
  `model` |
  `name` |
  `parameter` |
  `parents` |